#ifndef BISON_Y_TAB_H
# define BISON_Y_TAB_H

# ifndef YYSTYPE
#  define YYSTYPE int
#  define YYSTYPE_IS_TRIVIAL 1
# endif

#ifndef YYLTYPE
typedef struct yyltype
{
  int first_line;
  int first_column;

  int last_line;
  int last_column;
} yyltype;

# define YYLTYPE yyltype
# define YYLTYPE_IS_TRIVIAL 1
#endif

# define	OPT_TOKEN_WORD	257
# define	OPT_TOKEN_NUMBER	258
# define	OPT_TOKEN_STRING	259
# define	OPT_TOKEN_EQUALS	260


extern YYSTYPE yylval;

#endif /* not BISON_Y_TAB_H */
